pub struct LoginSubcommand {
pub project_path: PathBuf,
pub token: Option<String>,
pub api: Option<String>,
}Expand description
Log into a registry.
Fields
project_path: PathBufPath to a project to decide how to login
token: Option<String>GitHub auth token to set directly
api: Option<String>URL of the remote index to add an auth token for
Implementations