Module libwally::git_util[][src]

Contains helpers for wrangling git2.

A good source of ideas for how we should be interacting with Git is contained in Cargo’s git/utils.rs: https://github.com/rust-lang/cargo/blob/master/src/cargo/sources/git/utils.rs

Functions