Struct libwally::package_index::PackageIndex [−][src]
pub struct PackageIndex { /* fields omitted */ }Implementations
Publish a package to the local copy of the index and attempt to push it to the remote index, allowing a certain number of retries.
Note that this method does not interact with any remote registry servers; it’s intended for use with local registries or in the implementation of the registry server itself.
Read the list of versions for a package from the index.
Read the list of owners for a scope from the index
Check if a user id is present in the owners.json file for a scope