Struct libwally::package_name::PackageName [−][src]
pub struct PackageName { /* fields omitted */ }Expand description
Refers to a package, but not a specific version. Package names consist of a scope and name.
Both the scope and name portions of a package name must consist only of
lowercase letters, digits, and dashes (-).
Examples of package names:
hello/worldosyrisrblx/t
Implementations