pub struct InMemoryRegistry { /* private fields */ }Expand description
An in-memory registry that can have packages published to it.
InMemoryRegistry itself is not a PackageSource, but one can be created
by calling source().
Implementations
Sourceimpl InMemoryRegistry
impl InMemoryRegistry
pub fn new() -> Self
Sourcepub fn publish(&self, builder: PackageBuilder)
pub fn publish(&self, builder: PackageBuilder)
Publish a new package to the registry.
Sourcepub fn source(&self) -> PackageSource
pub fn source(&self) -> PackageSource
Returns a handle to an object that can be used as a PackageSource.