Struct libwally::package_source::Registry[][src]

pub struct Registry { /* fields omitted */ }

Implementations

Create a Registry from a registry spec, which usually comes from the registry field of a package manifest.