pub struct TestRegistry { /* fields omitted */ }
Update this package source, if it has state that needs to be updated.
Query this package source for all of the packages that match this
PackageReq. Read more
Downloads the contents of a package given its fully-qualified
PackageId. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,