Struct libwally::resolution::Resolve [−][src]
pub struct Resolve {
pub activated: BTreeSet<PackageId>,
pub metadata: BTreeMap<PackageId, ResolvePackageMetadata>,
pub shared_dependencies: BTreeMap<PackageId, BTreeMap<String, PackageId>>,
pub server_dependencies: BTreeMap<PackageId, BTreeMap<String, PackageId>>,
}Expand description
A completely resolved graph of packages returned by resolve.
State here is stored in multiple maps, all keyed by PackageId, to facilitate concurrent mutable access to unrelated information about different packages.
Fields
activated: BTreeSet<PackageId>Set of all packages that have been chosen to be part of the package graph.
metadata: BTreeMap<PackageId, ResolvePackageMetadata>Metadata stored about each package that does not need to be accessed concurrently to other information.
Graph of all dependencies originating from the “shared” dependency realm.
server_dependencies: BTreeMap<PackageId, BTreeMap<String, PackageId>>Graph of all dependencies originating from the “server” dependency realm.