Struct libwally::manifest::Package[][src]

pub struct Package {
    pub name: PackageName,
    pub version: Version,
    pub registry: String,
    pub realm: Realm,
    pub description: Option<String>,
    pub license: Option<String>,
    pub authors: Vec<String>,
}

Fields

name: PackageName

The scope and name of the package.

Example: lpghatguy/asink.

version: Version

The current version of the package.

Example: 1.0.0

registry: String

The registry that this package should pull its dependencies from.

Example: https://github.com/UpliftGames/wally-test-index

realm: Realm

The realms (shared, server, etc) that this package can be used in.

Packages in the shared realm can only depend on other shared packages. Packages in the server realm can depend on any other package.

Example: shared, server

description: Option<String>

A short description of the package.

Example: A game about adopting things.

license: Option<String>

An SPDX license specifier for the package.

Example: MIT OR Apache-2.0

authors: Vec<String>

A list of the package’s authors.

Example: [“Biff Lumfer biff@playadopt.me”]