Struct libwally::package_contents::PackageContents [−][src]
pub struct PackageContents { /* fields omitted */ }Expand description
Container for the contents of a package that have been downloaded.
Implementations
Unpack the package into the given path on the filesystem.
Create a new PackageContents object from a buffer.