pub struct InMemoryRegistry { /* fields omitted */ }
An in-memory registry that can have packages published to it.
InMemoryRegistry itself is not a PackageSource, but one can be created
by calling source().
Publish a new package to the registry.
Returns a handle to an object that can be used as a PackageSource.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,