Struct libwally::package_source::InMemoryRegistry[][src]

pub struct InMemoryRegistry { /* fields omitted */ }
An in-memory registry that can have packages published to it.

InMemoryRegistry itself is not a PackageSource, but one can be created by calling source().

Implementations

Publish a new package to the registry.

Returns a handle to an object that can be used as a PackageSource.