Trait libwally::package_source::PackageSource [−][src]
pub trait PackageSource {
fn update(&self) -> Result<()>;
fn query(&self, package_req: &PackageReq) -> Result<Vec<Manifest>>;
fn download_package(
&self,
package_id: &PackageId
) -> Result<PackageContents>;
}Required methods
Update this package source, if it has state that needs to be updated.
Query this package source for all of the packages that match this
PackageReq.
fn download_package(&self, package_id: &PackageId) -> Result<PackageContents>
fn download_package(&self, package_id: &PackageId) -> Result<PackageContents>
Downloads the contents of a package given its fully-qualified
PackageId.